LogDispatcher class

Dispatcher to manage logger workers in an isolate.

Constructors

LogDispatcher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createWorker(String id, Map<String, dynamic> config) → void
Creates a logger worker in the isolate. id is the unique identifier for the worker. config is the configuration map for the worker.
dispose() Future<void>
disposeWorker(String id) → void
Disposes the worker in the isolate. id is the unique identifier for the worker.
init() Future<void>
Initializes the dispatcher and spawns the isolate.
log(String id, String message) → void
Sends a log message to the worker in the isolate. id is the unique identifier for the worker.
registerWorker(String id, WorkerCreator creator) → void
Registers a worker creator in the isolate. id is the unique identifier for the worker type. creator is the function that creates the worker.