unregisterWorker static method
Unregisters a worker creator by its unique identifier.
id is the unique identifier for the worker type.
Implementation
static void unregisterWorker(String id) {
workers.remove(id);
}
Unregisters a worker creator by its unique identifier.
id is the unique identifier for the worker type.
static void unregisterWorker(String id) {
workers.remove(id);
}